@@ -201,14 +201,15 @@ summarize_domains <- function(simulation_results, domain_variable = "domain_id")
 #' @importFrom tibble rownames_to_column as_tibble
 #' @param simulation_results Simulation results dataframe.
 #' @param results_dir Directory to place simulation files.
-#' @export
+#'
 #' @return Tibble with paths to the created data files.
+#' @export
 #' @examples
 #' \dontrun{
 #' data(mc_simulation_results)
-#' summarize_to_disk(mc_simulation_results)
+#' summarize_to_disk(mc_simulation_results, results_dir = tempdir())
 #' }
-summarize_to_disk <- function(simulation_results, results_dir = "~/results") {
+summarize_to_disk <- function(simulation_results, results_dir) {
   if (!dir.exists(results_dir)) dir.create(results_dir)
 
   scenario_summary <- summarize_scenarios(simulation_results)
